/* set up your libname */
libname big 'xxx';

/* Set min, max for each variable. Visual inspection used here: could be
 * computed and rounded up as well */
%let v1=minTemp; %let min_v1 = 4;   %let max_v1 = 24;   /* minTemp */
%let v2=maxTemp; %let min_v2 = 16;  %let max_v2 = 36;   /* maxTemp */
%let v3=temp9am; %let min_v3 = 8;   %let max_v3 = 28;   /* temp9am */
%let v4=cloud9am; %let min_v4 = 2;  %let max_v4 = 7;   /* cloud9am */
%let v5=rainfall; %let min_v5 = 0;  %let max_v5 = 5;  /* rainfall */
%let v6=windSpeed9am; %let min_v6 = 4;  %let max_v6 = 24;  /* windSpeed9am */

/* Calculate the ranges */
%let range_v1 = %sysevalf(&max_v1 - &min_v1);
%let range_v2 = %sysevalf(&max_v2 - &min_v2);
%let range_v3 = %sysevalf(&max_v3 - &min_v3);
%let range_v4 = %sysevalf(&max_v4 - &min_v4);
%let range_v5 = %sysevalf(&max_v5 - &min_v5);
%let range_v6 = %sysevalf(&max_v6 - &min_v6);

proc means data=big.weather_aus ;
  where location IN ( 'Brisbane', 'Katherine', 'Melbourne', 'Perth',
                      'Newcastle', 'Sydney', 'Canberra',
                      'Hobart', 'Uluru', 'WaggaWagga', 'Wollongong')
        ;
  class location;
  var &v1 &v2 &v3 &v4 &v5 &v6;
  output out=means mean=;
run;

/* Normalize the values */
data par_axis_norm;
 set means(firstobs=2 drop=_type_); 
  /* use computed means, exclude overall (first) obs */

  do ;
    x = 1; y = &v1; y_pct = (&v1 - &min_v1) / &range_v1;
    output;
    x = 2; y = &v2; y_pct = (&v2 - &min_v2) / &range_v2;
    output;
    x = 3; y = &v3; y_pct = (&v3 - &min_v3) / &range_v3;
    output;
    x = 4; y = &v4; y_pct = (&v4 - &min_v4) / &range_v4;
    output;
    x = 5; y = &v5; y_pct = (&v5 - &min_v5) / &range_v5;
    output;
    x = 6; y = &v6; y_pct = (&v6 - &min_v6) / &range_v6;
    output;

   end;
run;

data y_axis_ticks;
  drop i increment;
  attrib tvalue format=Best4.;
  axis_x = 1; axis_y = 0;
  tvalue=&min_v1;
  increment = 0.2 * &range_v1;
  output;
  do i=1 to 5;
    axis_y = axis_y + 0.2;
    tvalue = tvalue + increment;
    output;
  end;

  axis_x = 2; axis_y = 0;
  tvalue=&min_v2;
  increment = 0.2 * &range_v2;
  output;
  do i=1 to 5;
    axis_y = axis_y + 0.2;
    tvalue = tvalue + increment;
    output;
  end;

  axis_x = 3; axis_y = 0;
  tvalue=&min_v3;
  increment = 0.2 * &range_v3;
  output;
  do i=1 to 5;
    axis_y = axis_y + 0.2;
    tvalue = tvalue + increment;
    output;
  end;

  axis_x = 4; axis_y = 0;
  tvalue=&min_v4;
  increment = 0.2 * &range_v4;
  output;
  do i=1 to 5;
    axis_y = axis_y + 0.2;
    tvalue = tvalue + increment;
    output;
  end;

  axis_x = 5; axis_y = 0;
  tvalue=&min_v5;
  increment = 0.2 * &range_v5;
  output;
  do i=1 to 5;
    axis_y = axis_y + 0.2;
    tvalue = tvalue + increment;
    output;
  end;

  axis_x = 6; axis_y = 0;
  tvalue=&min_v6;
  increment = 0.2 * &range_v6;
  output;
  do i=1 to 5;
    axis_y = axis_y + 0.2;
    tvalue = tvalue + increment;
    output;
  end;

run;

/* X axis labels */
data x_axis_labels;
  input pos label $15.;
  cards;
  1   Min Temp
  2   Max Temp
  3   Temp 9am
  4   Cloud 9am
  5   Rainfall
  6   Wind 9am
;
run;

data par_axis_final;
  merge par_axis_norm y_axis_ticks x_axis_labels;
run;

ods _all_ close; 
ods listing image_dpi=200 style=htmlBlue;
ods graphics / reset imagename='parallelAxis' width=6in;

proc sgplot data=par_axis_final noBorder;
title 'Weather in Australia (summmarized)';
  styleAttrs backColor=cxE0E7EF;

  refLine pos / axis=x lineAttrs=(color=grey thickness=10)
        transparency=0.6 label=label labelPos=min
        labelAttrs=(size=2.2%);

  series x=x y=y_pct / group=location transparency=0.4
        thickResp=_freq_ smoothConnect
        curveLabel curveLabelLoc=outside
        curveLabelAttrs=( weight=bold size=2%);
       
  text x=axis_x y=axis_y text=tvalue / textAttrs=(size=6 weight=bold);

  xAxis display=none offsetMin=0.02 offsetMax=0.02;
  yAxis display=none offsetMin=0.03 offsetMax=0.02;

footnote j=l height=7pt
        'Line thickness varies with obs: Katherine: 851, Canberra: 2709';
run;
title;
footnote;
